Class: Cb::TalentNetwork
- Inherits:
-
Object
- Object
- Cb::TalentNetwork
- Defined in:
- lib/cb/clients/talent_network_api.rb
Class Method Summary collapse
- .join_form_branding ⇒ Object
- .join_form_geography ⇒ Object
-
.join_form_questions(tndid, responsetype) ⇒ Object
Documentation: http://api.careerbuilder.com/TalentNetwork.aspx.
- .member_create ⇒ Object
Class Method Details
.join_form_branding ⇒ Object
15 16 17 |
# File 'lib/cb/clients/talent_network_api.rb', line 15 def self.join_form_branding ## Gets branding information (stylesheets, copytext, etc...) for the join form. end |
.join_form_geography ⇒ Object
19 20 21 |
# File 'lib/cb/clients/talent_network_api.rb', line 19 def self.join_form_geography ## Gets locations needed to fill the Geography question from the Join Form Question API end |
.join_form_questions(tndid, responsetype) ⇒ Object
Documentation: http://api.careerbuilder.com/TalentNetwork.aspx
8 9 10 11 12 13 |
# File 'lib/cb/clients/talent_network_api.rb', line 8 def self.join_form_questions(tndid, responsetype) ## Load the join form questions for a TalentNetworkDID responsetype = 'xml' if responsetype.blank? my_api = Cb::Utils::Api.new() cb_response = my_api.cb_get("#{Cb.configuration.uri_tn_join_questions}/#{tndid}/#{responsetype}") end |
.member_create ⇒ Object
23 24 25 |
# File 'lib/cb/clients/talent_network_api.rb', line 23 def self.member_create ## Creates a member based on the form built with the Join Form Questions API call end |