Module: Memory
- Defined in:
- lib/memory.rb
Defined Under Namespace
Classes: Analyzer, MemoryInfo
Constant Summary collapse
- REF_SIZE =
sizes are guessed, I was too lazy to look them up and then they are also platform dependent
4- OBJ_OVERHEAD =
?
4- FIXNUM_SIZE =
?
4
Class Method Summary collapse
Class Method Details
.analyze(*roots) ⇒ Object
12 13 14 15 16 |
# File 'lib/memory.rb', line 12 def self.analyze(*roots) an = Analyzer.new an.roots = roots an.analyze end |