Class: Cb::CbEducation
- Inherits:
-
Object
- Object
- Cb::CbEducation
- Defined in:
- lib/cb/models/implementations/cb_education.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Returns the value of attribute code.
-
#language ⇒ Object
Returns the value of attribute language.
-
#text ⇒ Object
Returns the value of attribute text.
Instance Method Summary collapse
-
#initialize(args = {}) ⇒ CbEducation
constructor
This object stores Education Codes having to do with a country.
Constructor Details
#initialize(args = {}) ⇒ CbEducation
This object stores Education Codes having to do with a country. The API objects dealing with job, will populate one or many of this object.
For more information, please visit: http://api.careerbuilder.com/v1/educationcodes
13 14 15 16 17 18 19 20 21 22 23 |
# File 'lib/cb/models/implementations/cb_education.rb', line 13 def initialize(args = {}) return if args.nil? @code = args['Code'] || '' @language = args['Name']['@language'] unless args['Name'].nil? @text = args['Name']['#text'] unless args['Name'].nil? # I have got to find a better way to do this @language ||= '' @text ||= '' end |
Instance Attribute Details
#code ⇒ Object
Returns the value of attribute code.
3 4 5 |
# File 'lib/cb/models/implementations/cb_education.rb', line 3 def code @code end |
#language ⇒ Object
Returns the value of attribute language.
3 4 5 |
# File 'lib/cb/models/implementations/cb_education.rb', line 3 def language @language end |
#text ⇒ Object
Returns the value of attribute text.
3 4 5 |
# File 'lib/cb/models/implementations/cb_education.rb', line 3 def text @text end |