Class: Cb::JobSearchCriteria
- Inherits:
-
Object
- Object
- Cb::JobSearchCriteria
- Extended by:
- Utils::FluidAttributes
- Defined in:
- lib/cb/criteria/job_search_criteria.rb
Overview
Trying to simplify the large number of inputs our job search api accepts For indepth information around all of the different inputs, please visit: http://api.careerbuilder.com/JobSearchInfo.aspx
Instance Method Summary collapse
Methods included from Utils::FluidAttributes
Instance Method Details
#search ⇒ Object
25 26 27 |
# File 'lib/cb/criteria/job_search_criteria.rb', line 25 def search Cb::JobApi.search(Cb::Utils::Api.criteria_to_hash(self)) end |