Class: Cb::JobSearchCriteria
- Inherits:
-
Object
- Object
- Cb::JobSearchCriteria
- Extended by:
- Utils::FluidAttributes
- Defined in:
- lib/cb/criteria/job_search_criteria.rb
Overview
Trying to simplify the large number of inputs our job search api accepts For indepth information around all of the different inputs, please visit: http://api.careerbuilder.com/JobSearchInfo.aspx